llmtorch 是一个用Python编写的大模型和深度学习API，运行在机器学习平台 Pytorch 之上。

目标是为开发者提供愉快的编程体验。

llmtorch 具有以下特点：

-   简单 -- 降低了开发者的认知负担，使您能够专注于问题中真正重要的部分，侧重于易用性、调试速度、代码优雅和简洁。
-   灵活 -- 简单的工作流应该快速且容易，而任意复杂的工作流应该通过一个清晰的路径可能构建在您已经学到的基础上。
-   强大 -- llmtorch 提供业界强大的性能和可扩展性。

### 安装方法

```python
pip install llmtorch
```